@@ -3,13 +3,31 @@ import pytest  # noqa
 
 import index_calculator._indices as indices
 
-from .conftest import pr_series, tas_series, tasmax_series, tasmin_series
+from .conftest import (
+    hurs_series,
+    mrt_series,
+    pr_series,
+    prsn_series,
+    rlds_series,
+    rlus_series,
+    rsds_series,
+    rsus_series,
+    sfcWind_series,
+    snd_series,
+    tas_series,
+    tasmax_series,
+    tasmin_series,
+)
 
 
 def tas_xarray(series=[-1, -10, 0, 15, 32, 6, -8]):
     return tas_series(np.array(series) + 273.15)
 
 
+def tas_c_xarray(series=[-15, -11, 0, 26, -32, 17, -9]):
+    return tas_series(np.array(series) + 273.15)
+
+
 def tasmin_xarray(series=[-1, -10, 0, 15, 32, 6, -8]):
     return tasmin_series(np.array(series) + 273.15)
 
@@ -22,6 +40,42 @@ def pr_xarray(series=[3, 4, 20, 20, 0, 6, 9]):
     return pr_series(np.array(series) / 86400)
 
 
+def prsn_xarray(series=[7, 0, 0.5, 10, 6, 0, 4]):
+    return prsn_series(np.array(series) / 86400)
+
+
+def snd_xarray(series=[0, 20, 150, 340, 170, 90, 0]):
+    return snd_series(np.array(series) / 100)
+
+
+def hurs_xarray(series=[50, 75, 25, 90, 10, 60, 30]):
+    return hurs_series(np.array(series))
+
+
+def rsds_xarray(series=[200, 250, 300, 350, 270, 230, 180]):
+    return rsds_series(np.array(series))
+
+
+def rsus_xarray(series=[30, 50, 100, 150, 70, 30, 8]):
+    return rsus_series(np.array(series))
+
+
+def rlds_xarray(series=[200, 250, 300, 350, 270, 230, 180]):
+    return rlds_series(np.array(series))
+
+
+def rlus_xarray(series=[30, 50, 100, 150, 70, 30, 8]):
+    return rlus_series(np.array(series))
+
+
+def sfcWind_xarray(series=[2, 18, 5, 10, 23, 1, 7]):
+    return sfcWind_series(np.array(series))
+
+
+def mrt_xarray(series=[-1, -10, 0, 15, 32, 6, -8]):
+    return mrt_series(np.array(series))
+
+
 def test_TG():
     result = indices.TG.compute(tas=tas_xarray(), freq="7D")
     np.testing.assert_allclose(result, 278, rtol=1e-03)
@@ -371,3 +425,73 @@ def test_DTR():
         freq="7D",
     )
     np.testing.assert_allclose(result, 0, rtol=1e-03)
+
+
+def test_CSf():
+    result = indices.CSf.compute(
+        tas=tas_c_xarray(),
+        freq="7D",
+        thresh=-10,
+        window=1,
+    )
+    np.testing.assert_allclose(result, 2, rtol=1e-03)
+
+
+def test_HSf():
+    result = indices.HSf.compute(
+        tasmax=tasmax_xarray(),
+        freq="7D",
+        thresh=27,
+        window=1,
+    )
+    np.testing.assert_allclose(result, 1, rtol=1e-03)
+
+
+def test_HSx():
+    result = indices.HSx.compute(
+        tasmax=tasmax_xarray(),
+        freq="7D",
+        thresh=27,
+        window=1,
+    )
+    np.testing.assert_allclose(result, 1, rtol=1e-03)
+
+
+def test_SD():
+    result = indices.SD.compute(
+        prsn=prsn_xarray(),
+        freq="7D",
+    )
+    np.testing.assert_allclose(result, 5, rtol=1e-03)
+
+
+def test_SCD():
+    result = indices.SCD.compute(
+        snd=snd_xarray(),
+        thresh=2,
+        freq="7D",
+    )
+    np.testing.assert_allclose(result, 5, rtol=1e-03)
+
+
+def test_Sfreq():
+    result = indices.Sfreq.compute(prsn=prsn_xarray(), freq="7D")
+    np.testing.assert_allclose(result, 5 / 7 * 100, rtol=1e-03)
+
+
+def test_Sint():
+    result = indices.Sint.compute(
+        prsn=prsn_xarray(),
+        freq="7D",
+    )
+    np.testing.assert_allclose(result, 17.63, rtol=1e-03)
+
+
+def test_UTCI():
+    result = indices.UTCI.compute(
+        tas=tas_xarray(),
+        hurs=hurs_xarray(),
+        sfcWind=sfcWind_xarray(),
+        mrt=mrt_xarray(),
+    )
+    np.testing.assert_allclose(result, [np.nan] * 7, rtol=1e-03)
